import setuptools

with open("README_client.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

with open("requirements-client.txt", "r") as f:
    requirements = f.read().splitlines()

setuptools.setup(
    name="LogQS",
    version="1.0.33",
    author="Nathan Margaglio",
    author_email="nmargaglio@carnegierobotics.com",
    description="A client for interacting with the LogQS Service.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/carnegierobotics/LogQS",
    project_urls={
        "Bug Tracker": "https://github.com/carnegierobotics/LogQS/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    include_package_data=True,
    packages=setuptools.find_packages(
        include=[
            "lqs",
            "lqs.client*",
            "lqs.interface*",
            "lqs.transcode*",
            "lqs.common*",
        ]
    ),
    python_requires=">=3.9",
    entry_points={
        "console_scripts": [
            "lqs=lqs.client.__main__:main",
            "lqs.client=lqs.client.__main__:main",
            "lqs.transcode=lqs.transcode.__main__:main",
        ],
    },
    install_requires=requirements,
)



from typing import Optional
from uuid import UUID

from pydantic import BaseModel

from lqs.interface.core.models.__common__ import (
    CommonModel,
    DataResponseModel,
    PaginationModel,
    optional_field,
    Int64,
)


class Tag(CommonModel):
    label_id: UUID
    log_id: UUID
    topic_id: Optional[UUID]

    note: Optional[str]
    context: Optional[dict]
    start_time: Optional[Int64]
    end_time: Optional[Int64]


class TagDataResponse(DataResponseModel[Tag]):
    pass


class TagListResponse(PaginationModel[Tag]):
    pass


class TagCreateRequest(BaseModel):
    label_id: UUID
    topic_id: Optional[UUID] = None

    note: Optional[str] = None
    context: Optional[dict] = None
    start_time: Optional[Int64] = None
    end_time: Optional[Int64] = None


class TagUpdateRequest(BaseModel):
    label_id: UUID = optional_field
    topic_id: Optional[UUID] = optional_field

    note: Optional[str] = optional_field
    context: Optional[dict] = optional_field
    start_time: Optional[Int64] = optional_field
    end_time: Optional[Int64] = optional_field



from lqs.interface.core import CreateInterface
from lqs.client.common import RESTInterface
import lqs.interface.core.models as models


class Create(CreateInterface, RESTInterface):
    service: str = "lqs"

    def __init__(self, app):
        super().__init__(app=app)

    def _api_key(self, **params):
        return self._create_resource("apiKeys", params, models.APIKeyDataResponse)

    def _digestion(self, **params):
        lock_token = params.pop("lock_token", None)
        return self._create_resource(
            "digestions",
            params,
            models.DigestionDataResponse,
            additiona_params={"lock_token": lock_token},
        )

    def _digestion_part(self, **params):
        digestion_id = params.pop("digestion_id")
        lock_token = params.pop("lock_token", None)
        return self._create_resource(
            f"digestions/{digestion_id}/parts",
            params,
            models.DigestionPartDataResponse,
            additiona_params={"lock_token": lock_token},
        )

    def _digestion_topic(self, **params):
        digestion_id = params.pop("digestion_id")
        lock_token = params.pop("lock_token", None)
        return self._create_resource(
            f"digestions/{digestion_id}/topics",
            params,
            models.DigestionTopicDataResponse,
            additiona_params={"lock_token": lock_token},
        )

    def _hook(self, **params):
        workflow_id = params.pop("workflow_id")
        return self._create_resource(
            f"workflows/{workflow_id}/hooks", params, models.HookDataResponse
        )

    def _group(self, **params):
        lock_token = params.pop("lock_token", None)
        return self._create_resource(
            "groups",
            params,
            models.GroupDataResponse,
            additiona_params={"lock_token": lock_token},
        )

    def _ingestion(self, **params):
        lock_token = params.pop("lock_token", None)
        return self._create_resource(
            "ingestions",
            params,
            models.IngestionDataResponse,
            additiona_params={"lock_token": lock_token},
        )

    def _ingestion_part(self, **params):
        ingestion_id = params.pop("ingestion_id")
        lock_token = params.pop("lock_token", None)
        return self._create_resource(
            f"ingestions/{ingestion_id}/parts",
            params,
            models.IngestionPartDataResponse,
            additiona_params={"lock_token": lock_token},
        )

    def _label(self, **params):
        return self._create_resource("labels", params, models.LabelDataResponse)

    def _log(self, **params):
        lock_token = params.pop("lock_token", None)
        return self._create_resource(
            "logs",
            params,
            models.LogDataResponse,
            additiona_params={"lock_token": lock_token},
        )

    def _log_object(self, **params):
        log_id = params.pop("log_id")
        lock_token = params.pop("lock_token", None)
        return self._create_resource(
            f"logs/{log_id}/objects",
            params,
            models.ObjectDataResponse,
            additiona_params={"lock_token": lock_token},
        )

    def _log_object_part(self, **params):
        log_id = params.pop("log_id")
        object_key = params.pop("object_key")
        return self._create_resource(
            f"logs/{log_id}/objects/{object_key}/parts",
            params,
            models.ObjectPartDataResponse,
        )

    def _object(self, **params):
        raise NotImplementedError

    def _object_part(self, **params):
        raise NotImplementedError

    def _object_store(self, **params):
        return self._create_resource(
            "objectStores", params, models.ObjectStoreDataResponse
        )

    def _query(self, **params):
        log_id = params.pop("log_id")
        lock_token = params.pop("lock_token", None)
        return self._create_resource(
            f"logs/{log_id}/queries",
            params,
            models.QueryDataResponse,
            additiona_params={"lock_token": lock_token},
        )

    def _record(self, **params):
        topic_id = params.pop("topic_id")
        lock_token = params.pop("lock_token", None)
        return self._create_resource(
            f"topics/{topic_id}/records",
            params,
            models.RecordDataResponse,
            additiona_params={"lock_token": lock_token},
        )

    def _role(self, **params):
        return self._create_resource("roles", params, models.RoleDataResponse)

    def _tag(self, **params):
        log_id = params.pop("log_id")
        lock_token = params.pop("lock_token", None)
        return self._create_resource(
            f"logs/{log_id}/tags",
            params,
            models.TagDataResponse,
            additiona_params={"lock_token": lock_token},
        )

    def _topic(self, **params):
        lock_token = params.pop("lock_token", None)
        return self._create_resource(
            "topics",
            params,
            models.TopicDataResponse,
            additiona_params={"lock_token": lock_token},
        )

    def _user(self, **params):
        return self._create_resource("users", params, models.UserDataResponse)

    def _workflow(self, **params):
        return self._create_resource("workflows", params, models.WorkflowDataResponse)



import os
import json
from pathlib import Path
from typing import Any, Dict, Tuple, Type, Optional, get_args

from pydantic import model_validator
from pydantic.fields import FieldInfo
from pydantic_settings import (
    BaseSettings,
    PydanticBaseSettingsSource,
    SettingsConfigDict,
)


class CommonConfig(BaseSettings):
    log_level: str = "INFO"
    log_as_json: bool = False
    log_to_file: bool = False
    config_path: str = "logqs-config.json"
    config_key: Optional[str] = None

    @model_validator(mode="before")
    @classmethod
    def parse_dict_fields(cls, data: Any):
        for key, value in data.items():
            accepts_dict = False
            if key not in cls.model_fields:
                continue
            annotation = cls.model_fields[key].annotation
            if annotation is dict:
                accepts_dict = True
            if dict in get_args(annotation):
                accepts_dict = True
            if list in get_args(annotation):
                accepts_dict = True
            if accepts_dict and isinstance(value, str):
                try:
                    data[key] = json.loads(value)
                except json.JSONDecodeError:
                    raise ValueError(
                        f"Could not parse {key} as JSON with value: {value}"
                    )
        return data

    @classmethod
    def settings_customise_sources(
        cls,
        settings_cls: Type[BaseSettings],
        init_settings: PydanticBaseSettingsSource,
        env_settings: PydanticBaseSettingsSource,
        dotenv_settings: PydanticBaseSettingsSource,
        file_secret_settings: PydanticBaseSettingsSource,
    ) -> Tuple[PydanticBaseSettingsSource, ...]:
        return (
            init_settings,
            JsonConfigSettingsSource(settings_cls),
            env_settings,
            dotenv_settings,
            file_secret_settings,
        )

    model_config = SettingsConfigDict(
        env_file=(".env.default", ".env", ".env.local", ".env.dev", ".env.prod"),
        env_prefix="LQS_",
        env_file_encoding="utf-8",
        case_sensitive=False,
        extra="ignore",
    )


class JsonConfigSettingsSource(PydanticBaseSettingsSource):
    def get_field_value(
        self, field: FieldInfo, field_name: str
    ) -> Tuple[Any, str, bool]:
        encoding = self.config.get("env_file_encoding")
        config_path = (
            self.settings_cls.model_fields["config_path"].default
            if self.settings_cls.model_fields.get("config_path")
            else "config.json"
        )
        if not os.path.exists(config_path):
            return None, field_name, False
        file_content_json = json.loads(Path(config_path).read_text(encoding))
        config_key = (
            self.settings_cls.model_fields["config_key"].default
            if self.settings_cls.model_fields.get("config_key")
            else None
        )
        if config_key:
            file_content_json = file_content_json.get(config_key)
        if not isinstance(file_content_json, dict):
            return None, field_name, False
        field_value = file_content_json.get(field_name)
        return field_value, field_name, False

    def prepare_field_value(
        self, field_name: str, field: FieldInfo, value: Any, value_is_complex: bool
    ) -> Any:
        return value

    def __call__(self) -> Dict[str, Any]:
        d: Dict[str, Any] = {}

        for field_name, field in self.settings_cls.model_fields.items():
            field_value, field_key, value_is_complex = self.get_field_value(
                field, field_name
            )
            field_value = self.prepare_field_value(
                field_name, field, field_value, value_is_complex
            )
            if field_value is not None:
                d[field_key] = field_value

        return d



from typing import Optional

from pydantic import BaseModel

from lqs.interface.core.models.__common__ import (
    CommonModel,
    DataResponseModel,
    PaginationModel,
    optional_field,
)


class Label(CommonModel):
    value: str
    note: Optional[str]


class LabelDataResponse(DataResponseModel[Label]):
    pass


class LabelListResponse(PaginationModel[Label]):
    pass


class LabelCreateRequest(BaseModel):
    value: str
    note: Optional[str] = None


class LabelUpdateRequest(BaseModel):
    value: str = optional_field
    note: Optional[str] = optional_field



from abc import abstractmethod
from typing import Optional
from uuid import UUID

from lqs.interface.base.update import UpdateInterface as BaseUpdateInterface
import lqs.interface.core.models as models


class UpdateInterface(BaseUpdateInterface):
    @abstractmethod
    def _digestion(self, **kwargs) -> models.DigestionDataResponse:
        pass

    def digestion(
        self,
        digestion_id: UUID,
        data: models.DigestionUpdateRequest,
        lock_token: Optional[str] = None,
    ):
        """
        Update a digestion.

        Args:
            digestion_id: The id of the digestion to update.
            data: The data to update the digestion with.
            lock_token: TODO: update this description
        Returns:
            A data response containing the updated digestion.
        """
        return self._digestion(
            digestion_id=digestion_id,
            data=self._process_data(data),
            lock_token=lock_token,
        )

    @abstractmethod
    def _digestion_part(self, **kwargs) -> models.DigestionPartDataResponse:
        pass

    def digestion_part(
        self,
        digestion_part_id: UUID,
        data: models.DigestionPartUpdateRequest,
        digestion_id: Optional[UUID] = None,
        lock_token: Optional[str] = None,
    ):
        """
        Update a digestion part.

        Args:
            digestion_part_id: The id of the digestion part to update.
            data: The data to update the digestion part with.
            digestion_id (optional): The id of the digestion to which the digestion part belongs.
        Returns:
            A data response containing the updated digestion part.
        """
        return self._digestion_part(
            digestion_id=digestion_id,
            digestion_part_id=digestion_part_id,
            data=self._process_data(data),
            lock_token=lock_token,
        )

    @abstractmethod
    def _digestion_topic(self, **kwargs) -> models.DigestionTopicDataResponse:
        pass

    def digestion_topic(
        self,
        digestion_topic_id: UUID,
        data: models.DigestionTopicUpdateRequest,
        digestion_id: Optional[UUID] = None,
        lock_token: Optional[str] = None,
    ):
        """
        Update a digestion topic.

        Args:
            digestion_topic_id: The id of the digestion topic to update.
            data: The data to update the digestion topic with.
            digestion_id (optional): The id of the digestion to which the digestion topic belongs.
        Returns:
            A data response containing the updated digestion topic.
        """
        return self._digestion_topic(
            digestion_id=digestion_id,
            digestion_topic_id=digestion_topic_id,
            data=self._process_data(data),
            lock_token=lock_token,
        )

    @abstractmethod
    def _group(self, **kwargs) -> models.GroupDataResponse:
        pass

    def group(
        self,
        group_id: UUID,
        data: models.GroupUpdateRequest,
        lock_token: Optional[str] = None,
    ):
        """
        Update a group.

        Args:
            group_id: The id of the group to update.
            data: The data to update the group with.
        Returns:
            A data response containing the updated group.
        """
        return self._group(
            group_id=group_id,
            data=self._process_data(data),
            lock_token=lock_token,
        )

    @abstractmethod
    def _hook(self, **kwargs) -> models.HookDataResponse:
        pass

    def hook(
        self,
        hook_id: UUID,
        data: models.HookUpdateRequest,
        workflow_id: Optional[UUID] = None,
    ):
        """
        Update a hook.

        Args:
            hook_id: The id of the hook to update.
            data: The data to update the hook with.
            workflow_id (optional): The id of the workflow to which the hook belongs.
        Returns:
            A data response containing the updated hook.
        """
        return self._hook(
            workflow_id=workflow_id,
            hook_id=hook_id,
            data=self._process_data(data),
        )

    @abstractmethod
    def _ingestion(self, **kwargs) -> models.IngestionDataResponse:
        pass

    def ingestion(
        self,
        ingestion_id: UUID,
        data: models.IngestionUpdateRequest,
        lock_token: Optional[str] = None,
    ):
        """
        Update an ingestion.

        Args:
            ingestion_id: The id of the ingestion to update.
            data: The data to update the ingestion with.
        Returns:
            A data response containing the updated ingestion.
        """
        return self._ingestion(
            ingestion_id=ingestion_id,
            data=self._process_data(data),
            lock_token=lock_token,
        )

    @abstractmethod
    def _ingestion_part(self, **kwargs) -> models.IngestionPartDataResponse:
        pass

    def ingestion_part(
        self,
        ingestion_part_id: UUID,
        data: models.IngestionPartUpdateRequest,
        ingestion_id: Optional[UUID] = None,
        lock_token: Optional[str] = None,
    ):
        """
        Update an ingestion part.

        Args:
            ingestion_part_id: The id of the ingestion part to update.
            data: The data to update the ingestion part with.
            ingestion_id (optional): The id of the ingestion to which the ingestion part belongs.
        Returns:
            A data response containing the updated ingestion part.
        """
        return self._ingestion_part(
            ingestion_id=ingestion_id,
            ingestion_part_id=ingestion_part_id,
            data=self._process_data(data),
            lock_token=lock_token,
        )

    @abstractmethod
    def _label(self, **kwargs) -> models.LabelDataResponse:
        pass

    def label(self, label_id: UUID, data: models.LabelUpdateRequest):
        """
        Update a label.

        Args:
            label_id: The id of the label to update.
            data: The data to update the label with.
        Returns:
            A data response containing the updated label.
        """
        return self._label(
            label_id=label_id,
            data=self._process_data(data),
        )

    @abstractmethod
    def _log(self, **kwargs) -> models.LogDataResponse:
        pass

    def log(
        self,
        log_id: UUID,
        data: models.LogUpdateRequest,
        lock_token: Optional[str] = None,
    ):
        """
        Update a log.

        Args:
            log_id: The id of the log to update.
            data: The data to update the log with.
        Returns:
            A data response containing the updated log.
        """
        return self._log(
            log_id=log_id,
            data=self._process_data(data),
            lock_token=lock_token,
        )

    @abstractmethod
    def _log_object(self, **kwargs) -> models.ObjectDataResponse:
        pass

    def log_object(
        self,
        log_id: UUID,
        object_key: str,
        data: models.ObjectUpdateRequest,
        lock_token: Optional[str] = None,
    ):
        """
        Update a log object.

        Args:
            log_id: The id of the log to which the object belongs.
            object_key: The key of the object to update.
            data: The data to update the object with.
        Returns:
            A data response containing the updated object.
        """
        return self._log_object(
            log_id=log_id,
            object_key=object_key,
            data=self._process_data(data),
            lock_token=lock_token,
        )

    @abstractmethod
    def _object(self, **kwargs) -> models.ObjectDataResponse:
        pass

    def object(
        self, object_store_id: UUID, object_key: str, data: models.ObjectUpdateRequest
    ):
        """
        Update an object.

        Args:
            object_store_id: The id of the object store to which the object belongs.
            object_key: The key of the object to update.
            data: The data to update the object with.
        Returns:
            A data response containing the updated object.
        """
        return self._object(
            object_store_id=object_store_id,
            object_key=object_key,
            data=self._process_data(data),
        )

    @abstractmethod
    def _object_store(self, **kwargs) -> models.ObjectStoreDataResponse:
        pass

    def object_store(
        self, object_store_id: UUID, data: models.ObjectStoreUpdateRequest
    ):
        """
        Update an object store.

        Args:
            object_store_id: The id of the object store to update.
            data: The data to update the object store with.
        Returns:
            A data response containing the updated object store.
        """
        return self._object_store(
            object_store_id=object_store_id,
            data=self._process_data(data),
        )

    @abstractmethod
    def _query(self, **kwargs) -> models.QueryDataResponse:
        pass

    def query(
        self,
        query_id: UUID,
        data: models.QueryUpdateRequest,
        log_id: Optional[UUID] = None,
        lock_token: Optional[str] = None,
    ):
        """
        Update a query.

        Args:
            query_id: The id of the query to update.
            data: The data to update the query with.
            log_id (optional): The id of the log to which the query belongs.
        Returns:
            A data response containing the updated query.
        """
        return self._query(
            log_id=log_id,
            query_id=query_id,
            data=self._process_data(data),
            lock_token=lock_token,
        )

    @abstractmethod
    def _record(self, **kwargs) -> models.RecordDataResponse:
        pass

    def record(
        self,
        timestamp: models.Int64,
        topic_id: UUID,
        data: models.RecordUpdateRequest,
        lock_token: Optional[str] = None,
    ):
        """
        Update a record.

        Args:
            timestamp: The timestamp of the record to update.
            topic_id: The id of the topic to which the record belongs.
            data: The data to update the record with.
        Returns:
            A data response containing the updated record.
        """
        return self._record(
            timestamp=timestamp,
            topic_id=topic_id,
            data=self._process_data(data),
            lock_token=lock_token,
        )

    @abstractmethod
    def _tag(self, **kwargs) -> models.TagDataResponse:
        pass

    def tag(
        self, tag_id: UUID, data: models.TagUpdateRequest, log_id: Optional[UUID] = None, lock_token: Optional[str] = None
    ):
        """
        Update a tag.

        Args:
            tag_id: The id of the tag to update.
            data: The data to update the tag with.
            log_id (optional): The id of the log to which the tag belongs.
        Returns:
            A data response containing the updated tag.
        """
        return self._tag(
            log_id=log_id,
            tag_id=tag_id,
            data=self._process_data(data),
            lock_token=lock_token,
        )

    @abstractmethod
    def _topic(self, **kwargs) -> models.TopicDataResponse:
        pass

    def topic(
        self,
        topic_id: UUID,
        data: models.TopicUpdateRequest,
        lock_token: Optional[str] = None,
    ):
        """
        Update a topic.

        Args:
            topic_id: The id of the topic to update.
            data: The data to update the topic with.
        Returns:
            A data response containing the updated topic.
        """
        return self._topic(
            topic_id=topic_id,
            data=self._process_data(data),
            lock_token=lock_token,
        )

    @abstractmethod
    def _workflow(self, **kwargs) -> models.WorkflowDataResponse:
        pass

    def workflow(self, workflow_id: UUID, data: models.WorkflowUpdateRequest):
        """
        Update a workflow.

        Args:
            workflow_id: The id of the workflow to update.
            data: The data to update the workflow with.
        Returns:
            A data response containing the updated workflow.
        """
        return self._workflow(
            workflow_id=workflow_id,
            data=self._process_data(data),
        )



from lqs.interface.dsm import UpdateInterface
from lqs.client.common import RESTInterface
import lqs.interface.dsm.models as models


class Update(UpdateInterface, RESTInterface):
    service: str = "dsm"

    def __init__(self, app):
        super().__init__(app=app)

    def _announcement(self, **params):
        announcement_id = params.pop("announcement_id")
        data = params.pop("data")
        return self._update_resource(
            f"announcements/{announcement_id}",
            data,
            models.AnnouncementDataResponse,
        )

    def _api_key(self, **params):
        api_key_id = params.pop("api_key_id")
        data = params.pop("data")
        return self._update_resource(
            f"apiKeys/{api_key_id}", data, models.APIKeyDataResponse
        )

    def _comment(self, **params):
        comment_id = params.pop("comment_id")
        data = params.pop("data")
        return self._update_resource(
            f"comments/{comment_id}", data, models.CommentDataResponse
        )

    def _configuration(self, **params):
        configuration_id = params.pop("configuration_id")
        data = params.pop("data")
        return self._update_resource(
            f"configurations/{configuration_id}",
            data,
            models.ConfigurationDataResponse,
        )

    def _datastore(self, **params):
        datastore_id = params.pop("datastore_id")
        data = params.pop("data")
        return self._update_resource(
            f"dataStores/{datastore_id}", data, models.DataStoreDataResponse
        )

    def _datastore_association(self, **params):
        datastore_association_id = params.pop("datastore_association_id")
        data = params.pop("data")
        return self._update_resource(
            f"dataStoreAssociations/{datastore_association_id}",
            data,
            models.DataStoreAssociationDataResponse,
        )

    def _event(self, **params):
        event_id = params.pop("event_id")
        data = params.pop("data")
        return self._update_resource(
            f"events/{event_id}", data, models.EventDataResponse
        )

    def _job(self, **params):
        job_id = params.pop("job_id")
        data = params.pop("data")
        return self._update_resource(f"jobs/{job_id}", data, models.JobDataResponse)

    def _role(self, **params):
        role_id = params.pop("role_id")
        data = params.pop("data")
        return self._update_resource(f"roles/{role_id}", data, models.RoleDataResponse)

    def _user(self, **params):
        user_id = params.pop("user_id")
        data = params.pop("data")
        return self._update_resource(f"users/{user_id}", data, models.UserDataResponse)
